mathlib

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 23, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Abs

func Abs(args ...interface{}) (interface{}, error)

Abs returns the absolute value of a number

func Atn

func Atn(args ...interface{}) (interface{}, error)

Atn returns the arctangent of a number in radians

func Cos

func Cos(args ...interface{}) (interface{}, error)

Cos returns the cosine of an angle in radians

func Exp

func Exp(args ...interface{}) (interface{}, error)

Exp returns e raised to the power of the argument

func Int

func Int(args ...interface{}) (interface{}, error)

Int returns the integer part (floor) of a number

func Log

func Log(args ...interface{}) (interface{}, error)

Log returns the natural logarithm of a number

func Pow

func Pow(args ...interface{}) (interface{}, error)

Pow returns base raised to exponent power

func Rnd

func Rnd(args ...interface{}) (interface{}, error)

Rnd returns a random number between 0 and 1 if no argument, or between 0 and the specified value if an argument is provided

func Sin

func Sin(args ...interface{}) (interface{}, error)

Sin returns the sine of an angle in radians

func Sqr

func Sqr(args ...interface{}) (interface{}, error)

Sqr returns the square root of a number

func Tan

func Tan(args ...interface{}) (interface{}, error)

Tan returns the tangent of an angle in radians

Types

This section is empty.

Jump to