Documentation
¶
Index ¶
- func Abs(args ...interface{}) (interface{}, error)
- func Atn(args ...interface{}) (interface{}, error)
- func Cos(args ...interface{}) (interface{}, error)
- func Exp(args ...interface{}) (interface{}, error)
- func Int(args ...interface{}) (interface{}, error)
- func Log(args ...interface{}) (interface{}, error)
- func Pow(args ...interface{}) (interface{}, error)
- func Rnd(args ...interface{}) (interface{}, error)
- func Sin(args ...interface{}) (interface{}, error)
- func Sqr(args ...interface{}) (interface{}, error)
- func Tan(args ...interface{}) (interface{}, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Abs ¶
func Abs(args ...interface{}) (interface{}, error)
Abs returns the absolute value of a number
func Atn ¶
func Atn(args ...interface{}) (interface{}, error)
Atn returns the arctangent of a number in radians
func Cos ¶
func Cos(args ...interface{}) (interface{}, error)
Cos returns the cosine of an angle in radians
func Exp ¶
func Exp(args ...interface{}) (interface{}, error)
Exp returns e raised to the power of the argument
func Int ¶
func Int(args ...interface{}) (interface{}, error)
Int returns the integer part (floor) of a number
func Log ¶
func Log(args ...interface{}) (interface{}, error)
Log returns the natural logarithm of a number
func Pow ¶
func Pow(args ...interface{}) (interface{}, error)
Pow returns base raised to exponent power
func Rnd ¶
func Rnd(args ...interface{}) (interface{}, error)
Rnd returns a random number between 0 and 1 if no argument, or between 0 and the specified value if an argument is provided
func Sin ¶
func Sin(args ...interface{}) (interface{}, error)
Sin returns the sine of an angle in radians
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.